<?php
/**
 * Plugin Name:       Bulk Menu Edit
 * Plugin URI:        https://wordpress.org/plugins/bulk-menu-edit/
 * Description:       Bulk edit for WordPress menu
 * Version:           1.1.2
 * Tags:              menu, edit, bulk, items
 * Requires at least: 5.0 or higher
 * Requires PHP:      5.6
 * Tested up to:      5.7.2
 * Stable tag:        1.1.2
 * Author:            Michael Revellin-Clerc
 * Text Domain:       bulk-menu-edit
 * Domain Path:       /languages
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Contributors:      Michael Revellin-Clerc
 * Donate link:       https://ko-fi.com/devloper
 */

add_action( 'init', 'bulk_menu_edit_activated' );
function bulk_menu_edit_activated() {

    // Path of current plugin
    $plugin_path = plugin_basename( __FILE__ );

    // Execute only if plugin is activated
    if ( in_array( $plugin_path, apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {

        // Enqueue custom files
        add_action( 'admin_enqueue_scripts', 'bulk_menu_edit_enqueue_custom_files' );
        function bulk_menu_edit_enqueue_custom_files() {

            // Text Domain
            $text_domain = 'bulk-menu-edit';

            // Add JS
            wp_register_script( 'bulk-menu-js', plugin_dir_url( __FILE__ ) . '/assets/bulk-menu.js', $text_domain, array( 'wp-i18n' ), false );
            wp_set_script_translations( 'bulk-menu-js', $text_domain, plugin_dir_path( __FILE__ ) . 'languages' );
            wp_enqueue_script( 'bulk-menu-js', plugin_dir_url( __FILE__ ) . '/assets/bulk-menu.js', array( 'jquery' ), 'latest', false );

            // Add CSS
            wp_enqueue_style( 'bulk-menu-css', plugin_dir_url( __FILE__ ) . '/assets/bulk-menu.css', 'latest', 'all' );

            // Register URL for Ajax Call
            wp_localize_script( 'bulk-menu-ajax', 'ajaxurl', admin_url( 'admin-ajax.php' ) );

        }

        // Ajax call to remove menu items
        add_action( 'wp_ajax_remove_menu_items', 'bme_remove_menu_items' );
        function bme_remove_menu_items() {
            if ( isset( $_POST ) ) :
                $menu_items = $_POST['data'];
                foreach ( $menu_items as $data ) :
                    // Get only menu item value
                    $menu_item_id = preg_replace( '/[^0-9]/', '', $data['value'] );
                    // Delete post with current menu item
                    wp_delete_post( $menu_item_id );
                endforeach;
            endif;
        }
    }
}
add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'bme_plugin_manage_link', 10, 4 );
function bme_plugin_manage_link( $actions, $plugin_file, $plugin_data, $context ) {
    return array_merge( array( 'rate' => '' . __( '<a style="color:#4caf50;" target="_blank" href="https://wordpress.org/support/plugin/bulk-menu-edit/reviews/#new-post">Rate this ★</a>' ) . '' ), $actions );
}

